from .csv import Csv
from .json import JsonFile
from .tarfile import TarFile, TarFileGz
from .tsv import Tsv
from .zipfile import ZipFile
from .text import TextFile
from .html import HtmlFile
from .gunzipped import Gunzipped
